@@ -6,3 +6,5 @@ from .fcm import NotifyDeviceAdmin  # noqa
 from .template import NotifyTemplateAdmin  # noqa
 from .file import NotifyFileAdmin  # noqa
 from .user_list import NotifyUserListAdmin  # noqa
+from .system_log import SystemNotifyErrorLogInline  # noqa
+from .system_notify import SystemNotifyAdmin  # noqa
