@@ -1,4 +1,5 @@
 from django.db import models
+from django.db.models import Manager
 
 
 class NotifyCategory(models.Model):
@@ -6,6 +7,8 @@ class NotifyCategory(models.Model):
     template = models.TextField(verbose_name='Шаблон', default='{{text}}')
     created_at = models.DateTimeField(auto_now_add=True, verbose_name='Дата создания')
 
+    objects = Manager()
+
     def __str__(self):
         return self.title
 
