@@ -41,8 +41,7 @@ WHATS_APP_ACCOUNT_SID = None
 WHATS_APP_NUMBER_SENDER = None
 # SETTINGS
 EMAIL_MALLING = 1
-GARPIX_NOTIFY_MIXIN = 'garpix_notify.mixins.notify_mixin.NotifyMixin'
-GARPIX_SYSTEM_NOTIFY_MIXIN = 'garpix_notify.mixins.notify_mixin.NotifyMixin'
+
 NOTIFY_USER_WANT_MESSAGE_CHECK = None
 NOTIFY_CALL_CODE_CHECK = None
 GARPIX_NOTIFY_CELERY_SETTINGS = 'app.celery.app'
